@@ -221,27 +221,24 @@ libgnome_option_cb (poptContext ctx, enum poptCallbackReason reason,
 		case ARG_ESPEAKER:
 			g_value_init (&value, G_TYPE_STRING);
 			g_value_set_string (&value, opt->arg);
-			g_object_set (G_OBJECT (program),
-				      GNOME_PARAM_ESPEAKER, &value,
-				      NULL);
+			g_object_set_property (G_OBJECT (program),
+					       GNOME_PARAM_ESPEAKER, &value);
 			g_value_unset (&value);
 			break;
 
 		case ARG_DISABLE_SOUND:
 			g_value_init (&value, G_TYPE_BOOLEAN);
 			g_value_set_boolean (&value, FALSE);
-			g_object_set (G_OBJECT (program),
-				      GNOME_PARAM_ENABLE_SOUND, &value,
-				      NULL);
+			g_object_set_property (G_OBJECT (program),
+					       GNOME_PARAM_ENABLE_SOUND, &value);
 			g_value_unset (&value);
 			break;
 
 		case ARG_ENABLE_SOUND:
 			g_value_init (&value, G_TYPE_BOOLEAN);
 			g_value_set_boolean (&value, TRUE);
-			g_object_set (G_OBJECT (program),
-				      GNOME_PARAM_ENABLE_SOUND, &value,
-				      NULL);
+			g_object_set_property (G_OBJECT (program),
+					       GNOME_PARAM_ENABLE_SOUND, &value);
 			g_value_unset (&value);
 			break;
 
